@@ -61,3 +61,5 @@ class LoadoutSlot(IntEnum):
     KNIFE_CT = 3221225472
     KNIFE_T = 2147483648
     MUSIC_KIT = 3538944
+    GLOVES_T = 2150170624
+    GLOVES_CT = 3223912448
